Option Explicit

'========================================================================================
'                          .                 .
'                            ______ ______ .
'                         .:_\_ .  \\_ .__\_::.
'                      . .::./ ./  // ./__ .:::. .
'                         :_<_____/<______>_:.
'                         .                 .
'                   Damaged Cybernetics Laboratories
'
'    It is a crime to redistribute these routines in a commercial
'    venture of any kind without permission or a licensing agreement.
'    Contact us via email for more information on licensing.
'
'    This is freely distributable for non-commercial use, however we
'    require that you acknowledge the following:
'
'    Copyright (c) 1999 Damaged Cybernetics. All rights reserved.
'
'    If you have any questions or comments, please contact any of the
'    following people via the Internet:
'
'      Donald Moore    (MindRape)    moore@futureone.com
'========================================================================================
'Title:
'   Type Casting Operators for Visual Basic
'Author:
'   Donald Moore (MindRape)
'Purpose:
'   Eliminate the need for dummy/temporary variables in your code.
'   Instead type cast them!  I'm interested in any additions!
'========================================================================================



'=========================================================
'Public Function AsLong(Byref Expression as Variant) As Long
'Author: Donald Moore
'  Date: 06/16/99
'Parameters:
'   Expression As Variant
'Returns:
'   Long
'Purpose:
'   Cast the given expression as a Long
Public Function AsLong(ByRef Expression As Variant) As Long
On Error Resume Next
   AsLong = Expression
End Function



'=========================================================
'Public Function AsInteger(Byref Expression as Variant) As Integer
'Author: Donald Moore
'  Date: 06/16/99
'Parameters:
'   Expression As Variant
'Returns:
'   Integer
'Purpose:
'   Cast the given expression as an Integer
Public Function AsInteger(ByRef Expression As Variant) As Integer
On Error Resume Next
   AsInteger = Expression
End Function



'=========================================================
'Public Function AsByte(Byref Expression as Variant) As Byte
'Author: Donald Moore
'  Date: 06/16/99
'Parameters:
'   Expression As Variant
'Returns:
'   Byte
'Purpose:
'   Cast the given expression as a Byte
Public Function AsByte(ByRef Expression As Variant) As Byte
On Error Resume Next
   AsByte = Expression
End Function



'=========================================================
'Public Function AsBoolean(Byref Expression as Variant) As Boolean
'Author: Donald Moore
'  Date: 06/16/99
'Parameters:
'   Expression As Variant
'Returns:
'   Boolean
'Purpose:
'   Cast the given expression as a Boolean
Public Function AsBoolean(ByRef Expression As Variant) As Boolean
On Error Resume Next
    
    If VarType(Expression) = vbString Then
        Select Case UCase$(Expression)
            Case "YES", "TRUE", "RIGHT", "CORRECT", "YUP": AsBoolean = True
        End Select
    Else
        AsBoolean = Expression
    End If
End Function



'=========================================================
'Public Function AsCurrency(Byref Expression as Variant) As Currency
'Author: Donald Moore
'  Date: 06/16/99
'Parameters:
'   Expression As Variant
'Returns:
'   Currency
'Purpose:
'   Cast the given expression as a currency
Public Function AsCurrency(ByRef Expression As Variant) As Currency
On Error Resume Next
   AsCurrency = Expression
End Function



'=========================================================
'Public Function AsDate(Byref Expression as Variant) As Date
'Author: Donald Moore
'  Date: 06/16/99
'Parameters:
'   Expression As Variant
'Returns:
'   Date
'Purpose:
'   Cast the given expression as a Date
Public Function AsDate(ByRef Expression As Variant) As Date
On Error Resume Next
    AsDate = Expression
End Function



'=========================================================
'Public Function AsDouble(Byref Expression as Variant) As Double
'Author: Donald Moore
'  Date: 06/16/99
'Parameters:
'   Expression As Variant
'Returns:
'   Double
'Purpose:
'   Cast the given expression as a Double
Public Function AsDouble(ByRef Expression As Variant) As Double
On Error Resume Next
   AsDouble = Expression
End Function



'=========================================================
'Public Function AsDecimal(Byref Expression as Variant) As Decimal
'Author: Donald Moore
'  Date: 06/16/99
'Parameters:
'   Expression As Variant
'Returns:
'   Decimal
'Purpose:
'   Cast the given expression as a Double
Public Function AsDecimal(ByRef Expression As Variant) As Variant
On Error Resume Next
   AsDecimal = CDec(Expression)
End Function



'=========================================================
'Public Function AsString(Byref Expression as Variant) As String
'Author: Donald Moore
'  Date: 06/16/99
'Parameters:
'   Expression As Variant
'Returns:
'   String
'Purpose:
'   Cast the given expression as a String
Public Function AsString(ByRef Expression As Variant) As String
On Error Resume Next
   AsString = Expression
End Function



'=========================================================
'Public Function AsSingle(Byref Expression as Variant) As Single
'Author: Donald Moore
'  Date: 06/16/99
'Parameters:
'   Expression As Variant
'Returns:
'   Single
'Purpose:
'   Cast the given expression as a Single
Public Function AsSingle(ByRef Expression As Variant) As Single
On Error Resume Next
   AsSingle = Expression
End Function



'=========================================================
'Public Function AsHex(Number) As String
'Author: Donald Moore
'  Date: 06/16/99
'Parameters:
'   Expression As Variant
'Returns:
'   String
'Purpose:
'   Returns a string representing the hexadecimal value of a number
'Remarks:
'   should we include an optional boolean parameter to allow zero's to included or not? (double digits)
'   What about upper and lowercase?
Public Function AsHex(ByRef Expression As Variant, Optional ByVal bIsUpperCase As Boolean = True, Optional bAllowLeadingZeros As Boolean = False) As String
On Error Resume Next
Dim sHexValue As String

    sHexValue = VBA.Conversion.Hex$(Expression)

    'did we get a valid hex value?
    If (sHexValue <> vbNullString) Then
        'yup we did, now format it based on the given optional parameters
        If Not bIsUpperCase Then
            sHexValue = VBA.LCase$(sHexValue)
        End If
    
        If bAllowLeadingZeros Then
            If GetStringLength(sHexValue) Mod 2 Then
                sHexValue = "0" & sHexValue
            End If
        End If

        AsHex = sHexValue
    End If
    
End Function



'=========================================================
'Public Function asNull(Expression As Variant) As Variant
'Author: Donald Moore
'  Date: 06/16/99
'Parameters:
'   Expression As Variant
'Returns:
'   Variant
'Purpose:
'   Cast the given expression if it is a null string as a Null
Public Function AsNull(Expression As Variant) As Variant
On Error Resume Next
    AsNull = IIf(Expression = vbNullString, Null, Expression)
End Function

